<template>
	<el-dialog v-model="Shows" @close="handleClose(ruleFormRef)" :fullscreen="full" :title="titles" width="50%" draggable>
		<el-button @click="toggleFullscreen" size="small" class="pot" :icon="FullScreen"></el-button>
		<el-form :model="form" :disabled="disabled" ref="ruleFormRef" :rules="rules" label-width="120px">
			<el-row>
				<el-col :span="11">
					<el-form-item label="安全目标指标" prop="qName" size="default">
						<el-input v-model="form.qName" placeholder="请填写安全目标指标" />
					</el-form-item>
				</el-col>
				<el-col :span="11" :offset="2">
					<el-form-item label="目标指标编号" prop="indexNum" size="default">
						<el-input v-model="form.indexNum" placeholder="请填写目标指标编号" />
					</el-form-item>
				</el-col>
			</el-row>
			<el-row>
				<el-col :span="11">
					<el-form-item label="年度" prop="year" size="default">
						<el-input v-model.number="form.year" maxlength="8" placeholder="请填写年度" />
					</el-form-item>
				</el-col>
				<el-col :span="11" :offset="2">
					<el-form-item label="指标值" prop="value" size="default">
						<el-input v-model.number="form.value" placeholder="请填写指标值" />
					</el-form-item>
				</el-col>
			</el-row>
			<el-row>
				<el-col :span="11">
					<el-form-item label="指标级别" size="default" prop="level">
						<el-select v-model="form.level" placeholder="请选择" style="width: 100%">
							<el-option label="公司级" :value="1">公司级</el-option>
							<el-option label="部门分厂级" :value="2">部门分厂级</el-option>
							<el-option label="工段班组级" :value="3">工段班组级</el-option>
						</el-select>
					</el-form-item>
				</el-col>
				<el-col :span="11" :offset="2">
					<el-form-item label="完成期限" size="default" prop="completeDate">
						<el-date-picker
							v-model="form.completeDate"
							format="YYYY-MM-DD HH:mm:ss"
							value-format="YYYY-MM-DD HH:mm:ss"
							type="datetime"
							placeholder="请选择"
							style="width: 100%"
						/>
					</el-form-item>
				</el-col>
			</el-row>
			<el-form-item label="备注信息" prop="memo">
				<el-input v-model="form.memo" size="default" type="textarea" />
			</el-form-item>
		</el-form>
		<template #footer>
			<span class="dialog-footer">
				<el-button @click="resetForm(ruleFormRef)" size="default">关闭</el-button>
				<el-button type="primary" v-if="titles == '查看目标设定' ? false : true" @click="submitForm(ruleFormRef)" size="default">确定</el-button>
			</span>
		</template>
	</el-dialog>
</template>
<script lang="ts">
import { ref, toRefs, reactive, onMounted, watch, defineComponent } from 'vue';
// import { timeDate } from '/@/assets/index.ts';
import screenfull from 'screenfull';
import { ElMessageBox, ElMessage, ElButton, ElInput, TabsPaneContext } from 'element-plus';
import type { FormInstance, FormRules } from 'element-plus';
import { Plus, Delete, Upload, Download, Refresh, View, Search, FullScreen } from '@element-plus/icons-vue';
import { goalManagementApi } from '/@/api/goalManagement';
export default defineComponent({
	setup(props, { emit }) {
		let Shows = ref(false);
		const ruleFormRef = ref<FormInstance>();
		const form = ref({
			indexNum: '', //目标指标编号
			qName: '', //安全目标指标
			year: '', //年度
			level: '', ////指标级别 1:公司级 2:部门分厂级 3:工段班组级
			memo: '', ////备注信息
			targetType: '', ////指标类型 1:年指标 2:月指标
			completeDate: '', ////完成期限
			divideStatus: '2', ////分解状态 1:已分解 2:未分解
			value: '', ////指标值
		});
		const titles = ref();
		const disabled = ref(false);
		const titleT=ref()
		// 打开弹窗
		const openDialog = (title: string, value: any, id: number) => {
			Shows.value = true;
			titleT.value=title
			titles.value = `${title}目标设定`;
			form.value.targetType = value;
			disabled.value = title == '查看' ? true : false;
			if (title == '查看' || title == '修改')
				goalManagementApi()
					.getTargetMngDetail(id)
					.then((res) => {
						if (res.data.code == 200) {
							form.value = res.data.data;
							form.value.completeDate = timeC(form.value.completeDate);
						} else {
							ElMessage.error(res.data.msg);
						}
					});
		};
		const timeC = (timestamp: any) => {
			let a = new Date(timestamp).getTime();
			const date = new Date(a);
			const Y = date.getFullYear() + '-';
			const M = (date.getMonth() + 1 < 10 ? '0' + (date.getMonth() + 1) : date.getMonth() + 1) + '-';
			const D = (date.getDate() < 10 ? '0' + date.getDate() : date.getDate()) + '  ';
			const h = (date.getHours() < 10 ? '0' + date.getHours() : date.getHours()) + ':';
			const m = date.getMinutes() < 10 ? '0' + date.getMinutes() : date.getMinutes();
			const s = date.getSeconds(); // 秒
			const dateString = Y + M + D + h + m +`:${s}`;
			// console.log('dateString', dateString); // > dateString 2021-07-06 14:23
			return dateString;
		};
		//全屏
		const full = ref(false);
		const toggleFullscreen = () => {
			if (full.value == false) {
				full.value = true;
			} else {
				full.value = false;
			}
		};
		const rules = reactive<FormRules>({
			qName: [
				{
					required: true,
					message: '安全目标指标不能为空',
					trigger: 'change',
				},
			],
			indexNum: [
				{
					required: true,
					message: '目标指标编号不能为空',
					trigger: 'change',
				},
			],
			year: [
				{
					required: true,
					message: '年度不能为空',
					trigger: 'change',
				},
			],
			value: [
				{
					required: true,
					message: '指标值不能为空',
					trigger: 'change',
				},
				{
					type:"number",
					message: '指标值只能为数字类型',
					trigger: 'change',
				},
			],
			level: [],
			completeDate: [],
			memo: [],
		});
		// 提交
		const submitForm = async (formEl: FormInstance | undefined) => {
			if (!formEl) return;
			await formEl.validate((valid, fields) => {
				if (valid) {
					if(titleT.value=='新建'){
						delete form.value.id
					}	
					Shows.value = false;
					goalManagementApi()
						.getTargetMngAddOrupdata(form.value)
						.then((res) => {
							if (res.data.code == 200) {
								ElMessage({
									message: res.data.msg,
									type: 'success',
								});
								emit('navAddorUpdata');
							} else {
								ElMessage.error(res.data.msg);
								formEl.resetFields();
							}
						});
					formEl.resetFields();
				} else {
					console.log('error submit!', fields);
				}
			});
		};
		//   取消
		const resetForm = (formEl: FormInstance | undefined) => {
			if (!formEl) return;
			formEl.resetFields();
			Shows.value = false;
		};
		const handleClose = (formEl: FormInstance | undefined) => {
			formEl.resetFields();
		};
		return {
			timeC,
			openDialog,
			handleClose,
			titles,
			titleT,
			// timeDate,
			Shows,
			form,
			full,
			disabled,
			toggleFullscreen,
			rules,
			ruleFormRef,
			submitForm,
			resetForm,
			FullScreen,
		};
	},
});
</script>
<style scoped>
.el-row {
	padding: 0 0 20px 0;
}
</style>